==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/EphemeralVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EphemeralVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent<A>{
  public EphemeralVolumeSourceFluentImpl() {
  }
  public EphemeralVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.EphemeralVolumeSource instance) {
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder volumeClaimTemplate;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildVolumeClaimTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate getVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate buildVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public A withVolumeClaimTemplate(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate volumeClaimTemplate) {
    _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate);
    if (volumeClaimTemplate!=null){ this.volumeClaimTemplate= new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder(volumeClaimTemplate); _visitables.get("volumeClaimTemplate").add(this.volumeClaimTemplate);} return (A) this;
  }
  public java.lang.Boolean hasVolumeClaimTemplate() {
    return this.volumeClaimTemplate != null;
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplate() {
    return new io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplateLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate item) {
    return new io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate());
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplateLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate item) {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EphemeralVolumeSourceFluentImpl that = (EphemeralVolumeSourceFluentImpl) o;
    if (volumeClaimTemplate != null ? !volumeClaimTemplate.equals(that.volumeClaimTemplate) :that.volumeClaimTemplate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(volumeClaimTemplate,  additionalProperties,  super.hashCode());
  }
  public class VolumeClaimTemplateNestedImpl<N> extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl<io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<N>> implements io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    VolumeClaimTemplateNestedImpl(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate item) {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder(this, item);
    }
    VolumeClaimTemplateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder builder;
    public N and() {
      return (N) EphemeralVolumeSourceFluentImpl.this.withVolumeClaimTemplate(builder.build());
    }
    public N endVolumeClaimTemplate() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/EphemeralVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EphemeralVolumeSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent<A>{
  public EphemeralVolumeSourceFluentImpl() {
  }
  public EphemeralVolumeSourceFluentImpl(io.fabric8.kubernetes.api.model.EphemeralVolumeSource instance) {
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder volumeClaimTemplate;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildVolumeClaimTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate getVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate buildVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null?this.volumeClaimTemplate.build():null;
  }
  public A withVolumeClaimTemplate(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate volumeClaimTemplate) {
    _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate);
    if (volumeClaimTemplate!=null){ this.volumeClaimTemplate= new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder(volumeClaimTemplate); _visitables.get("volumeClaimTemplate").add(this.volumeClaimTemplate);} return (A) this;
  }
  public java.lang.Boolean hasVolumeClaimTemplate() {
    return this.volumeClaimTemplate != null;
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplate() {
    return new io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplateLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate item) {
    return new io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate());
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplateLike(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate item) {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EphemeralVolumeSourceFluentImpl that = (EphemeralVolumeSourceFluentImpl) o;
    if (volumeClaimTemplate != null ? !volumeClaimTemplate.equals(that.volumeClaimTemplate) :that.volumeClaimTemplate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(volumeClaimTemplate,  additionalProperties,  super.hashCode());
  }
  public class VolumeClaimTemplateNestedImpl<N> extends io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateFluentImpl<io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<N>> implements io.fabric8.kubernetes.api.model.EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    VolumeClaimTemplateNestedImpl(io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplate item) {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder(this, item);
    }
    VolumeClaimTemplateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PersistentVolumeClaimTemplateBuilder builder;
    public N and() {
      return (N) EphemeralVolumeSourceFluentImpl.this.withVolumeClaimTemplate(builder.build());
    }
    public N endVolumeClaimTemplate() {
      return and();
    }
    
  }
  
}
